# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

Summary: Reverse proxy, load balancer and HTTPS front-end for Web servers
Name: pound
Version: 4.15
Release: 1%{?dist}
License: GPL-3.0-or-later
Group: System Environment/Daemons
URL: https://github.com/graygnuorg/%{name}
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: https://github.com/graygnuorg/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1: %{name}.cfg
Source2: %{name}.%{_servicefile_postfix}
%if %{_has_systemd}
Source3: %{name}-tmpfiles.conf
%endif
Patch0: pound-4.7-man_page.patch
# patches >=100 will/should be fixed in SCM
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Requires(pre): /usr/sbin/groupadd, /usr/sbin/useradd
Requires(post): openssl, coreutils
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
BuildRequires: openssl-devel, pkgconfig, sed, %{__perl}
%if 0%{?rhel} <= 6
BuildRequires: pcre-devel
%else
BuildRequires: pcre2-devel
%endif

%description
The %{name} program is a reverse proxy, load balancer and HTTPS
front-end for Web servers. %{name} was developed to enable
distributing the load among several Web servers and to allow for
a convenient TLS wrapper for those Web servers that do not offer
it natively.

%prep
%setup -q
%patch0 -p1 -b .man_page
%{__install} -m 0644 -p %{SOURCE1} ./

# adjust rundir path in config and other files
for f in %{name}.cfg doc/%{name}.8; do
  %{__sed} -e "s@\/var\/run@%{_pidbasedir}@g" $f > ${f}.$$
  if [ $f = %{name}.cfg ]; then
    touch -r $f ${f}.$$
  fi
  %{__mv} -vf ${f}.$$ $f
done

%build
%configure \
  --sysconfdir=%{_sysconfdir}/%{name} \
  --disable-tcmalloc \
  --disable-hoard \
  --enable-pcre \
  --with-owner=%{name} \
  --with-group=%{name} \
%{nil}

%{__make} CPPFLAGS="-DPOUND_PID=\\\"%{_pidbasedir}/%{name}/%{name}.pid\\\""

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}
 
%{__install} -d %{buildroot}%{_sysconfdir}/%{name}
%{__install} -d %{buildroot}%{_sysconfdir}/pki/%{name}
%{__install} -d %{buildroot}%{_var}/empty/%{name}
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE3} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE2} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{name}.cfg %{buildroot}%{_sysconfdir}/%{name}/

%{__make} install DESTDIR=%{buildroot} INSTALL="install -p"

# installed, but not packaged in rpm
%{__rm} -f %{buildroot}%{_infodir}/dir

# create ghost pem file
touch %{buildroot}%{_sysconfdir}/pki/%{name}/%{name}.pem

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
getent group %{name} > /dev/null || groupadd -r %{name} 2> /dev/null || :
getent passwd %{name} > /dev/null || \
  useradd -g %{name} -s /sbin/nologin -r -c "Pound User" -d %{_var}/empty/%{name} %{name} 2> /dev/null || :

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

# Not needed with >=EL9
install-info %{_infodir}/%{name}.info.gz %{_infodir}/dir || :

# create self-signed TLS certificate
if [ ! -f %{_sysconfdir}/pki/%{name}/%{name}.pem ]; then
  umask 0077
  CERTPARAMS="--\nSomeState\nSomeCity\nSomeOrganization\nSomeOrganizationalUnit\n$(hostname)\nroot@$(hostname)"
  CERT=$(mktemp /tmp/cert.XXXXXXXX)
  KEY=$(mktemp /tmp/key.XXXXXXXX)
  echo -e "$CERTPARAMS" |
    openssl req -newkey rsa:2048 -x509 -nodes -days 3653 -set_serial $RANDOM -out $CERT -keyout $KEY > /dev/null 2>&1
  RETVAL=$?
  if [ $RETVAL -eq 0 ]; then
    {
      %{__cat} $CERT
      echo ""
      %{__cat} $KEY
    } > %{_sysconfdir}/pki/%{name}/%{name}.pem
    %{__chmod} 0640 %{_sysconfdir}/pki/%{name}/%{name}.pem
    %{__chown} root.%{name} %{_sysconfdir}/pki/%{name}/%{name}.pem
  fi
  %{__rm} -f $CERT $KEY
fi
exit 0

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

# Not needed with >=EL9
if [ $1 -eq 0 ]; then
  install-info --delete %{_infodir}/%{name}.info.gz %{_infodir}/dir || :
fi

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog* COPYING NEWS README THANKS
%{_sbindir}/%{name}
%{_bindir}/%{name}ctl
%{_datadir}/%{name}/mvh.inc
%{_datadir}/%{name}/%{name}ctl.tmpl
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.cfg
%dir %{_sysconfdir}/pki/%{name}
%attr(0640,root,%{name}) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/%{name}/%{name}.pem
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%else
%config %{_initrddir}/%{name}
%endif
%{_mandir}/man5/%{name}*.5*
%{_mandir}/man8/%{name}*.8*
%{_infodir}/%{name}.info*
%attr(0711,root,root) %dir %{_var}/empty/%{name}
%attr(0775,root,%{name}) %dir %{_pidbasedir}/%{name}

%changelog
* Mon Jan 13 2025 Simon Matter <simon.matter@invoca.ch> 4.15-1
- update to release 4.15

* Mon Aug 26 2024 Simon Matter <simon.matter@invoca.ch> 4.13-1
- update to release 4.13

* Fri Apr 26 2024 Simon Matter <simon.matter@invoca.ch> 4.12-1
- update to release 4.12

* Wed Jan 17 2024 Simon Matter <simon.matter@invoca.ch> 4.11-1
- update to release 4.11

* Sat Oct 14 2023 Simon Matter <simon.matter@invoca.ch> 4.10-1
- update to release 4.10

* Wed Aug 23 2023 Simon Matter <simon.matter@invoca.ch> 4.9-1
- update to release 4.9

* Tue May 30 2023 Simon Matter <simon.matter@invoca.ch> 4.8-1
- update to release 4.8

* Mon May 22 2023 Simon Matter <simon.matter@invoca.ch> 4.7-2
- change to *.common.service systemd files
- change to SPDX license tag
- add two patches from upstream

* Tue Apr 18 2023 Simon Matter <simon.matter@invoca.ch> 4.7-1
- update to release 4.7

* Thu Apr 06 2023 Simon Matter <simon.matter@invoca.ch> 4.7-0.6
- update to current prerelease 4.7
- add new Control options to default config

* Tue Apr 04 2023 Simon Matter <simon.matter@invoca.ch> 4.7-0.5
- update to current prerelease 4.7
- move pid file to [/var]/run/pound/ and fix permissions of the directory

* Sat Apr 01 2023 Simon Matter <simon.matter@invoca.ch> 4.7-0.1
- update to current prerelease 4.7

* Mon Mar 13 2023 Simon Matter <simon.matter@invoca.ch> 4.6-1
- update to release 4.6

* Mon Jan 10 2022 Simon Matter <simon.matter@invoca.ch> 2.8-5
- add support for EL9

* Tue Apr 21 2020 Simon Matter <simon.matter@invoca.ch> 2.8-4
- add support for EL8

* Thu Dec 27 2018 Simon Matter <simon.matter@invoca.ch> 2.8-3
- add websocket patch
- add fallback_scsv patch

* Sat Jun 16 2018 Simon Matter <simon.matter@invoca.ch> 2.8-2
- add patch to Stop if BIO_read returns <= 0
- preserve timestamp in config file

* Fri May 11 2018 Simon Matter <simon.matter@invoca.ch> 2.8-1
- update to release 2.8
- add two patches from debian

* Fri Sep 04 2015 Simon Matter <simon.matter@invoca.ch> 2.7-6
- add NormalizeIPv4 patch

* Wed Apr 29 2015 Simon Matter <simon.matter@invoca.ch> 2.7-5
- cosmetic spec file fixes

* Tue Feb 03 2015 Simon Matter <simon.matter@invoca.ch> 2.7-2
- add support for systemd

* Mon Jan 26 2015 Simon Matter <simon.matter@invoca.ch> 2.7-1
- update to release 2.7

* Mon Dec 29 2014 Simon Matter <simon.matter@invoca.ch> 2.7-0.f.1
- update to release 2.7f

* Tue Dec 09 2014 Simon Matter <simon.matter@invoca.ch> 2.7-0.e.3
- update to release 2.7e

* Mon Oct 20 2014 Simon Matter <simon.matter@invoca.ch> 2.7-0.d.2
- do not print stderr from init script while starting up

* Mon Oct 20 2014 Simon Matter <simon.matter@invoca.ch> 2.7-0.d.1
- update to release 2.7d

* Fri Jun 21 2013 Simon Matter <simon.matter@invoca.ch> 2.6-2
- use more secure ciphers in default config

* Fri Dec 30 2011 Simon Matter <simon.matter@invoca.ch> 2.6-1
- update to release 2.6

* Tue Aug 02 2011 Simon Matter <simon.matter@invoca.ch> 2.5-6
- run ad user pound
- change chroot jail to /var/empty/pound

* Mon Aug 01 2011 Simon Matter <simon.matter@invoca.ch> 2.5-5
- setup chroot directory in init script

* Mon Aug 01 2011 Simon Matter <simon.matter@invoca.ch> 2.5-4
- build with standard malloc, no google-perftools or hoard

* Thu Jun 16 2011 Simon Matter <simon.matter@invoca.ch> 2.5-3
- add memory_leak patch

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 2.5-2
- mass rebuild

* Tue Feb 02 2010 Simon Matter <simon.matter@invoca.ch> 2.5-1
- update to release 2.5

* Thu Dec 17 2009 Simon Matter <simon.matter@invoca.ch> 2.4.5-2
- add fix to make configure detect GNU libc compatible malloc

* Mon Jun 29 2009 Simon Matter <simon.matter@invoca.ch> 2.4.5-1
- update to release 2.4.5

* Wed Jan 14 2009 Simon Matter <simon.matter@invoca.ch> 2.4.4-1
- update to release 2.4.4

* Tue Sep 30 2008 Simon Matter <simon.matter@invoca.ch> 2.4.3-2
- preserve config file timestamp while upgrading pki location

* Sat May 31 2008 Simon Matter <simon.matter@invoca.ch> 2.4.3-1
- update to release 2.4.3

* Thu Apr 24 2008 Simon Matter <simon.matter@invoca.ch> 2.4.2-1
- update to release 2.4.2

* Mon Apr 07 2008 Simon Matter <simon.matter@invoca.ch> 2.4.1-1
- update to release 2.4.1

* Fri Mar 28 2008 Simon Matter <simon.matter@invoca.ch> 2.4-3
- disable real-time scheduling, patch by Samuel Graenacher

* Fri Feb 29 2008 Simon Matter <simon.matter@invoca.ch> 2.4-2
- don't report duplicate syslog messages, use correct local time

* Mon Feb 11 2008 Simon Matter <simon.matter@invoca.ch> 2.4-1
- update to release 2.4

* Tue Aug 28 2007 Simon Matter <simon.matter@invoca.ch> 2.3.2-2
- fix handling of certificates on new distributions

* Fri May 18 2007 Simon Matter <simon.matter@invoca.ch> 2.3.2-1
- update to release 2.3.2

* Tue May 01 2007 Simon Matter <simon.matter@invoca.ch> 2.3.1-1
- update to release 2.3.1

* Tue Apr 17 2007 Simon Matter <simon.matter@invoca.ch> 2.3-2
- modify init script to not add /lib/libgcc* to chroot jail on startup

* Wed Apr 11 2007 Simon Matter <simon.matter@invoca.ch> 2.3-1
- update to release 2.3

* Thu Apr 05 2007 Simon Matter <simon.matter@invoca.ch> 2.2.8-1
- update to release 2.2.8

* Mon Mar 12 2007 Simon Matter <simon.matter@invoca.ch> 2.2.7-1
- update to release 2.2.7

* Tue Mar 06 2007 Simon Matter <simon.matter@invoca.ch> 2.2.6-2
- build with TCMalloc from google-perftools

* Fri Mar 02 2007 Simon Matter <simon.matter@invoca.ch> 2.2.6-1
- update to release 2.2.6

* Tue Feb 20 2007 Simon Matter <simon.matter@invoca.ch> 2.2.5-1
- update to release 2.2.5

* Sat Feb 10 2007 Simon Matter <simon.matter@invoca.ch> 2.2.4-1
- update to release 2.2.4

* Tue Jan 23 2007 Simon Matter <simon.matter@invoca.ch> 2.2.3-2
- replace logging patch

* Sat Jan 20 2007 Simon Matter <simon.matter@invoca.ch> 2.2.3-1
- update to release 2.2.3

* Tue Jan 16 2007 Simon Matter <simon.matter@invoca.ch> 2.2.2-1
- update to release 2.2.2

* Wed Jan 03 2007 Simon Matter <simon.matter@invoca.ch> 2.2.1-1
- update to release 2.2.1

* Tue Jan 02 2007 Simon Matter <simon.matter@invoca.ch> 2.2-2
- add sprintf_overrun patch

* Sat Dec 16 2006 Simon Matter <simon.matter@invoca.ch> 2.2-1
- update to release 2.2

* Sat Dec 09 2006 Simon Matter <simon.matter@invoca.ch> 2.1.8-1
- update to release 2.1.8

* Thu Dec 07 2006 Simon Matter <simon.matter@invoca.ch> 2.1.7-1
- update to release 2.1.7
- add pound-2.1.7-make patch

* Sun Nov 19 2006 Simon Matter <simon.matter@invoca.ch> 2.1.6-2
- add bottleneck patch

* Sat Nov 04 2006 Simon Matter <simon.matter@invoca.ch> 2.1.6-1
- update to release 2.1.6

* Thu Nov 02 2006 Simon Matter <simon.matter@invoca.ch> 2.1.5-2
- add emergency_back-end patch

* Mon Oct 23 2006 Simon Matter <simon.matter@invoca.ch> 2.1.5-1
- update to release 2.1.5

* Sat Oct 14 2006 Simon Matter <simon.matter@invoca.ch> 2.1.4-1
- update to release 2.1.4

* Tue Sep 26 2006 Simon Matter <simon.matter@invoca.ch> 2.1.3-3
- add no_cont patch

* Fri Sep 22 2006 Simon Matter <simon.matter@invoca.ch> 2.1.3-2
- small spec file changes

* Thu Sep 21 2006 Simon Matter <simon.matter@invoca.ch> 2.1.3-1
- update to release 2.1.3

* Tue Sep 19 2006 Simon Matter <simon.matter@invoca.ch> 2.1.2-1
- update to release 2.1.2
- remove msdav build option

* Mon Sep 11 2006 Simon Matter <simon.matter@invoca.ch> 2.1.1-1
- update to release 2.1.1

* Wed Aug 30 2006 Simon Matter <simon.matter@invoca.ch> 2.1-2
- add loglevel2 patch

* Mon Aug 07 2006 Simon Matter <simon.matter@invoca.ch> 2.1-1
- update to release 2.1

* Fri Jun 23 2006 Simon Matter <simon.matter@invoca.ch> 2.0.9-1
- update to release 2.0.9

* Tue Jun 20 2006 Simon Matter <simon.matter@invoca.ch> 2.0.8-1
- update to release 2.0.8

* Tue Jun 06 2006 Simon Matter <simon.matter@invoca.ch> 2.0.7-1
- update to release 2.0.7

* Mon May 22 2006 Simon Matter <simon.matter@invoca.ch> 2.0.6-1
- update to release 2.0.6

* Mon May 15 2006 Simon Matter <simon.matter@invoca.ch> 2.0.5-1
- update to release 2.0.5

* Fri May 05 2006 Simon Matter <simon.matter@invoca.ch> 2.0.4-4
- remove /dev bind mount from the init script

* Thu May 04 2006 Simon Matter <simon.matter@invoca.ch> 2.0.4-3
- modify init script to add /lib/libgcc* to chroot jail on startup

* Mon Mar 20 2006 Simon Matter <simon.matter@invoca.ch> 2.0.4-1
- update to release 2.0.4
- build using posixpcre

* Tue Feb 21 2006 Simon Matter <simon.matter@invoca.ch> 2.0.2-1
- update to release 2.0.2

* Mon Feb 06 2006 Simon Matter <simon.matter@invoca.ch> 2.0.1-1
- update to release 2.0.1

* Wed Feb 01 2006 Simon Matter <simon.matter@invoca.ch> 2.0-1
- update to release 2.0

* Wed Jan 04 2006 Simon Matter <simon.matter@invoca.ch> 2.0-0.b6_1
- update to release 2.0b6

* Sat Dec 24 2005 Simon Matter <simon.matter@invoca.ch> 2.0-0.b5_1
- update to release 2.0b5

* Fri Dec 16 2005 Simon Matter <simon.matter@invoca.ch> 2.0-0.b4_4
- replace timeout patch, add fixed svc.c

* Tue Dec 13 2005 Simon Matter <simon.matter@invoca.ch> 2.0-0.b4_2
- add haportaddr patch
- add timeout patch

* Wed Dec 07 2005 Simon Matter <simon.matter@invoca.ch> 2.0-0.b4_1
- update to release 2.0b4
- add patch to make check-only mode work with 2.x code

* Fri Nov 18 2005 Simon Matter <simon.matter@invoca.ch> 2.0-0.b3_1
- update to release 2.0b3

* Wed Nov 09 2005 Simon Matter <simon.matter@invoca.ch> 2.0-0.b2_1
- update to release 2.0b2
- remove HTTPS config patch

* Tue Nov 01 2005 Simon Matter <simon.matter@invoca.ch> 2.0-0.b1_1
- update to release 2.0b1

* Mon Oct 24 2005 Simon Matter <simon.matter@invoca.ch> 1.9.4-1
- update to release 1.9.4

* Wed Sep 28 2005 Simon Matter <simon.matter@invoca.ch> 1.9.3-1
- update to release 1.9.3

* Mon Sep 26 2005 Simon Matter <simon.matter@invoca.ch> 1.9.2-1
- update to release 1.9.2

* Tue Aug 30 2005 Simon Matter <simon.matter@invoca.ch> 1.9.1-3
- fix new pkg-config stuff

* Mon Aug 29 2005 Simon Matter <simon.matter@invoca.ch> 1.9.1-2
- make build work on systems without pkg-config

* Mon Aug 29 2005 Simon Matter <simon.matter@invoca.ch> 1.9.1-1
- update to release 1.9.1
- pull in CPPFLAGS and LDFLAGS from openssl's pkg-config data, if it exists

* Mon Aug 22 2005 Simon Matter <simon.matter@invoca.ch> 1.9-3
- cosmetic changes in pre and post scripts

* Fri Aug 19 2005 Simon Matter <simon.matter@invoca.ch> 1.9-2
- fix ssl pki stuff to handle new locations

* Thu Jun 02 2005 Simon Matter <simon.matter@invoca.ch>
- updated to release 1.9

* Thu May 19 2005 Simon Matter <simon.matter@invoca.ch>
- updated to release 1.8.5

* Mon May 09 2005 Simon Matter <simon.matter@invoca.ch>
- updated to release 1.8.4

* Tue Apr 26 2005 Simon Matter <simon.matter@invoca.ch>
- updated to release 1.8.3

* Tue Mar 08 2005 Simon Matter <simon.matter@invoca.ch>
- updated to second release of 1.8.2

* Mon Mar 07 2005 Simon Matter <simon.matter@invoca.ch>
- updated to release 1.8.2

* Sat Feb 12 2005 Simon Matter <simon.matter@invoca.ch>
- updated to release 1.8.1

* Tue Dec 14 2004 Simon Matter <simon.matter@invoca.ch>
- added buildreq for openssl-devel

* Mon Nov 08 2004 Simon Matter <simon.matter@invoca.ch>
- updated to release 1.8

* Tue Mar 30 2004 Simon Matter <simon.matter@invoca.ch>
- added poll patch

* Wed Mar 24 2004 Simon Matter <simon.matter@invoca.ch>
- updated to release 1.7

* Tue Mar 23 2004 Simon Matter <simon.matter@invoca.ch>
- updated to -current release

* Mon Jan 19 2004 Simon Matter <simon.matter@invoca.ch>
- updated to -current release

* Fri Nov 07 2003 Simon Matter <simon.matter@invoca.ch>
- added FAQ

* Tue Oct 21 2003 Simon Matter <simon.matter@invoca.ch>
- chroot jail uses bind mount to get access to /dev/*

* Thu Oct 16 2003 Simon Matter <simon.matter@invoca.ch>
- binaries go to /usr/sbin/

* Tue Oct 14 2003 Simon Matter <simon.matter@invoca.ch>
- updated to release 1.5

* Fri Oct 03 2003 Simon Matter <simon.matter@invoca.ch>
- updated snapshot release

* Fri Sep 26 2003 Simon Matter <simon.matter@invoca.ch>
- updated snapshot release

* Wed Sep 24 2003 Simon Matter <simon.matter@invoca.ch>
- updated snapshot release

* Thu Sep 11 2003 Simon Matter <simon.matter@invoca.ch>
- updated snapshot release

* Wed Aug 13 2003 Simon Matter <simon.matter@invoca.ch>
- added new configure options

* Thu Jul 03 2003 Simon Matter <simon.matter@invoca.ch>
- small config fixes

* Mon May 12 2003 Simon Matter <simon.matter@invoca.ch>
- disable msdav support by default

* Tue Apr 29 2003 Simon Matter <simon.matter@invoca.ch>
- fixed RootJail configuration

* Sun Apr 27 2003 Simon Matter <simon.matter@invoca.ch>
- enable msdav support

* Sat Apr 26 2003 Simon Matter <simon.matter@invoca.ch>
- initial build
